Module: Faraday::NestedParamsEncoder

Extended by:
DecodeMethods, EncodeMethods, Forwardable
Defined in:
lib/faraday/encoders/nested_params_encoder.rb

Overview

This is the default encoder for Faraday requests. Using this encoder, parameters will be encoded respecting their structure, so you can send objects such as Arrays or Hashes as parameters for your requests.

Class Attribute Summary collapse

Method Summary

Methods included from EncodeMethods

encode

Methods included from DecodeMethods

decode

Class Attribute Details

.array_indicesObject

Returns the value of attribute array_indices.



178
179
180
# File 'lib/faraday/encoders/nested_params_encoder.rb', line 178

def array_indices
  @array_indices
end

.param_depth_limitObject

Returns the value of attribute param_depth_limit.



178
179
180
# File 'lib/faraday/encoders/nested_params_encoder.rb', line 178

def param_depth_limit
  @param_depth_limit
end

.sort_paramsObject

Returns the value of attribute sort_params.



178
179
180
# File 'lib/faraday/encoders/nested_params_encoder.rb', line 178

def sort_params
  @sort_params
end